local _, private = ...

--[[ Lua Globals ]]
-- luacheck: globals next

--[[ Core ]]
local Aurora = private.Aurora
local Base = Aurora.Base
local Hook, Skin = Aurora.Hook, Aurora.Skin
local Util = Aurora.Util

do --[[ AddOns\Blizzard_TalentUI.lua ]]
    function Hook.PlayerTalentFrameSpec_OnLoad(self)
        local numSpecs = _G.GetNumSpecializations(false, self.isPet)
        local sex = self.isPet and _G.UnitSex("pet") or _G.UnitSex("player")

        for i = 1, numSpecs do
            local button = self["specButton"..i]
            local _, _, _, icon = _G.GetSpecializationInfo(i, false, self.isPet, nil, sex)
            button.specIcon:SetTexture(icon)

            local role = _G.GetSpecializationRole(i, false, self.isPet)
            Base.SetTexture(button.roleIcon, "icon"..role)

            Skin.PlayerSpecButtonTemplate(button)
        end
    end
    function Hook.PlayerTalentFrame_UpdateTabs(playerLevel)
        local prev
        for i = 1, _G.NUM_TALENT_FRAME_TABS do
            local tab = _G["PlayerTalentFrameTab"..i]
            if tab:IsShown() then
                tab:ClearAllPoints()
                if not prev then
                    tab:SetPoint("TOPLEFT", _G.PlayerTalentFrame, "BOTTOMLEFT", 20, -1)
                else
                    tab:SetPoint("TOPLEFT", prev, "TOPRIGHT", 1, 0)
                end
                prev = tab
            end
        end
    end
    function Hook.PlayerTalentFrame_CreateSpecSpellButton(self, index)
        Skin.PlayerSpecSpellTemplate(self.spellsScroll.child["abilityButton"..index])
    end
    function Hook.PlayerTalentFrame_UpdateSpecFrame(self, spec)
        local playerTalentSpec = _G.GetSpecialization(nil, self.isPet)
        local shownSpec = spec or playerTalentSpec or 1
        local sex = self.isPet and _G.UnitSex("pet") or _G.UnitSex("player")

        local scrollChild = self.spellsScroll.child
        local specID, _, _, specIcon = _G.GetSpecializationInfo(shownSpec, nil, self.isPet, nil, sex)
        scrollChild.specIcon:SetTexture(specIcon)

        local role = _G.GetSpecializationRole(shownSpec, nil, self.isPet)
        if role then
            Base.SetTexture(scrollChild.roleIcon, "icon"..role)
        end

        local index = 1
        local bonuses
        local bonusesIncrement = 1
        if self.isPet then
            bonuses = {_G.GetSpecializationSpells(shownSpec, nil, self.isPet, true)}
            -- GetSpecializationSpells adds a spell level after each spell ID, but we only care about the spell ID
            bonusesIncrement = 2
        else
            bonuses = _G.C_SpecializationInfo.GetSpellsDisplay(specID)
        end

        if bonuses then
            for i = 1, #bonuses, bonusesIncrement do
                local frame = scrollChild["abilityButton"..index]

                -- First ability already has anchor set
                if index > 1 then
                    if (index % 2) == 0 then
                        frame:SetPoint("LEFT", scrollChild["abilityButton"..(index - 1)], "RIGHT", 110, 0)
                    else
                        frame:SetPoint("TOP", scrollChild["abilityButton"..(index - 2)], "BOTTOM", 0, 0)
                    end
                end

                local _, spellIcon = _G.GetSpellTexture(bonuses[i])
                frame.icon:SetTexture(spellIcon)
                index = index + 1
            end
        end
    end
end

do --[[ AddOns\Blizzard_TalentUI.xml ]]
    function Skin.TalentTabTemplate(Button)
        Skin.CharacterFrameTabButtonTemplate(Button)
        Button._auroraTabResize = true
    end
    function Skin.TalentBranchTemplate(Texture)
    end
    function Skin.TalentArrowTemplate(Texture)
    end
    function Skin.TalentButtonTemplate(Button)
        Skin.FrameTypeItemButton(Button)

        local name = Button:GetName()
        _G[name.."Slot"]:Hide()
    end
end

function private.AddOns.Blizzard_TalentUI()
    local TalentFrame = _G.TalentFrame
    Base.SetBackdrop(TalentFrame)
    local bg = TalentFrame:GetBackdropTexture("bg")
    bg:SetPoint("TOPLEFT", 14, -14)
    bg:SetPoint("BOTTOMRIGHT", -34, 75)

    local portrait, tl, tr, bl, br = TalentFrame:GetRegions()
    portrait:Hide()
    tl:Hide()
    tr:Hide()
    bl:Hide()
    br:Hide()

    local textures = {
        TopLeft = {
            point = "TOPLEFT",
            x = 286, -- textureSize * (frameSize / fullBGSize)
            y = 327,
        },
        TopRight = {
            x = 72,
            y = 327,
        },
        BottomLeft = {
            x = 286,
            y = 163,
        },
        BottomRight = {
            x = 72,
            y = 163,
        },
    }
    for name, info in next, textures do
        local tex = _G["TalentFrameBackground"..name]
        if info.point then
            tex:SetPoint(info.point, bg)
        end
        tex:SetSize(info.x, info.y)
        tex:SetDrawLayer("BACKGROUND", 3)
        tex:SetAlpha(0.7)
    end

    _G.TalentFrameTitleText:ClearAllPoints()
    _G.TalentFrameTitleText:SetPoint("TOPLEFT", bg)
    _G.TalentFrameTitleText:SetPoint("BOTTOMRIGHT", bg, "TOPRIGHT", 0, -private.FRAME_TITLE_HEIGHT)

    _G.TalentFramePointsLeft:Hide()
    _G.TalentFramePointsMiddle:Hide()
    _G.TalentFramePointsRight:Hide()

    _G.TalentFrameSpentPoints:SetPoint("TOP", _G.TalentFrameTitleText, "BOTTOM", 0, 5)

    Skin.UIPanelCloseButton(_G.TalentFrameCloseButton)
    Skin.UIPanelButtonTemplate(_G.TalentFrameCancelButton)

    Skin.TalentTabTemplate(_G.TalentFrameTab1)
    Skin.TalentTabTemplate(_G.TalentFrameTab2)
    Skin.TalentTabTemplate(_G.TalentFrameTab3)
    Skin.TalentTabTemplate(_G.TalentFrameTab4)
    Skin.TalentTabTemplate(_G.TalentFrameTab5)
    Util.PositionRelative("TOPLEFT", bg, "BOTTOMLEFT", 20, -1, 1, "Right", {
        _G.TalentFrameTab1,
        _G.TalentFrameTab2,
        _G.TalentFrameTab3,
        _G.TalentFrameTab4,
        _G.TalentFrameTab5,
    })

    _G.TalentFrameScrollFrame:ClearAllPoints()
    _G.TalentFrameScrollFrame:SetPoint("TOPLEFT", bg, 5, -45)
    _G.TalentFrameScrollFrame:SetPoint("BOTTOMRIGHT", bg, -25, 30)
    Skin.UIPanelScrollFrameTemplate(_G.TalentFrameScrollFrame)
    local top, bottom = _G.TalentFrameScrollFrame:GetRegions()
    top:Hide()
    bottom:Hide()

    for i = 1, _G.MAX_NUM_TALENTS do
        Skin.TalentButtonTemplate(_G["TalentFrameTalent"..i])
    end
end
