local _, private = ...

--[[ Lua Globals ]]
-- luacheck: globals pcall select

--[[ Core ]]
local Aurora = private.Aurora
local Base = Aurora.Base
local Hook, Skin = Aurora.Hook, Aurora.Skin
local Color = Aurora.Color

do --[[ AddOns\Blizzard_TradeSkillUI.lua ]]
    function Hook.TradeSkillFrame_SetSelection(id)
        if not _G.TradeSkillSkillIcon._auroraSkinned then
            local skinned = pcall(Base.CropIcon, _G.TradeSkillSkillIcon:GetNormalTexture(), _G.TradeSkillSkillIcon)
            _G.TradeSkillSkillIcon._auroraSkinned = skinned
        end
    end
end

do --[[ AddOns\Blizzard_TradeSkillUI.xml ]]
    function Skin.TradeSkillSkillButtonTemplate(Frame)
        Skin.ClassTrainerSkillButtonTemplate(Frame)
    end
    function Skin.TradeSkillItemTemplate(Frame)
        Skin.QuestItemTemplate(Frame)
    end
end

function private.AddOns.Blizzard_TradeSkillUI()
    _G.hooksecurefunc("TradeSkillFrame_SetSelection", Hook.TradeSkillFrame_SetSelection)

    local TradeSkillFrame = _G.TradeSkillFrame
    Base.SetBackdrop(TradeSkillFrame)
    local bg = TradeSkillFrame:GetBackdropTexture("bg")
    bg:SetPoint("TOPLEFT", 14, -14)
    bg:SetPoint("BOTTOMRIGHT", -34, 75)

    local portrait, tl, tr, bl, br = TradeSkillFrame:GetRegions()
    portrait:Hide()
    tl:Hide()
    tr:Hide()
    bl:Hide()
    br:Hide()

    local titleText = _G.TradeSkillFrameTitleText
    titleText:ClearAllPoints()
    titleText:SetPoint("TOPLEFT", bg)
    titleText:SetPoint("BOTTOMRIGHT", bg, "TOPRIGHT", 0, -private.FRAME_TITLE_HEIGHT)

    local borderLeft, borderRight = select(7, TradeSkillFrame:GetRegions())
    borderLeft:Hide()
    borderRight:Hide()

    local barLeft, barRight = select(9, TradeSkillFrame:GetRegions())
    barLeft:SetColorTexture(Color.gray:GetRGB())
    barLeft:SetPoint("TOPLEFT", bg, 10, -210)
    barLeft:SetPoint("BOTTOMRIGHT", bg, "TOPRIGHT", -10, -211)
    barRight:Hide()

    Skin.FrameTypeStatusBar(_G.TradeSkillRankFrame)
    _G.TradeSkillRankFrame:SetPoint("TOPLEFT", bg, 20, -30)
    _G.TradeSkillRankFrame:SetPoint("TOPRIGHT", bg, -20, -30)
    _G.TradeSkillRankFrameSkillName:SetPoint("LEFT", 6, 0)
    _G.TradeSkillRankFrameBackground:Hide()
    _G.TradeSkillRankFrameBorder:Hide()

    local left, middle, right = _G.TradeSkillExpandButtonFrame:GetRegions()
    left:Hide()
    middle:Hide()
    right:Hide()
    Skin.ClassTrainerSkillButtonTemplate(_G.TradeSkillCollapseAllButton)

    Skin.UIDropDownMenuTemplate(_G.TradeSkillInvSlotDropDown)
    Skin.UIDropDownMenuTemplate(_G.TradeSkillSubClassDropDown)

    for i = 1, _G.TRADE_SKILLS_DISPLAYED do
        Skin.TradeSkillSkillButtonTemplate(_G["TradeSkillSkill"..i])
    end

    Skin.ClassTrainerListScrollFrameTemplate(_G.TradeSkillListScrollFrame)
    Skin.ClassTrainerDetailScrollFrameTemplate(_G.TradeSkillDetailScrollFrame)
    local headerLeft, headerRight = select(5, _G.TradeSkillDetailScrollChildFrame:GetRegions())
    headerLeft:Hide()
    headerRight:Hide()

    for i = 1, _G.MAX_TRADE_SKILL_REAGENTS do
        Skin.TradeSkillItemTemplate(_G["TradeSkillReagent"..i])
    end

    Skin.UIPanelButtonTemplate(_G.TradeSkillCreateButton)
    Skin.UIPanelButtonTemplate(_G.TradeSkillCancelButton)
    Skin.UIPanelButtonTemplate(_G.TradeSkillCreateAllButton)

    do -- NumericInputSpinner
        local function SpinnerButton(Button)
            Skin.FrameTypeButton(Button)
            Button:SetBackdropOption("offsets", {
                left = 3,
                right = 3,
                top = 3,
                bottom = 3,
            })
            local buttonBG = Button:GetBackdropTexture("bg")
            local arrow = Button:CreateTexture(nil, "ARTWORK")
            arrow:SetPoint("TOPLEFT", buttonBG, 6, -3)
            arrow:SetPoint("BOTTOMRIGHT", buttonBG, -6, 3)
            return arrow
        end

        Base.SetTexture(SpinnerButton(_G.TradeSkillDecrementButton), "arrowLeft")

        Skin.FrameTypeEditBox(_G.TradeSkillInputBox)
        _G.TradeSkillInputBoxLeft:Hide()
        _G.TradeSkillInputBoxRight:Hide()
        _G.TradeSkillInputBoxMiddle:Hide()

        local inputBG = _G.TradeSkillInputBox:GetBackdropTexture("bg")
        inputBG:ClearAllPoints()
        inputBG:SetHeight(20)
        inputBG:SetPoint("LEFT", -5, 0)
        inputBG:SetPoint("RIGHT", 0, 0)

        Base.SetTexture(SpinnerButton(_G.TradeSkillIncrementButton), "arrowRight")
    end

    Skin.UIPanelCloseButton(_G.TradeSkillFrameCloseButton)
end
