local _, private = ...

--[[ Lua Globals ]]
-- luacheck: globals next

--[[ Core ]]
local Aurora = private.Aurora
local Base = Aurora.Base
local Skin = Aurora.Skin
local Color = Aurora.Color

--do --[[ AddOns\Blizzard_WorldMap.lua ]]
--end

do --[[ AddOns\Blizzard_WorldMap.xml ]]
    do --[[ Blizzard_WorldMapTemplates.xml ]]
        function Skin.WorldMapFloorNavigationFrameTemplate(Frame)
            Skin.UIDropDownMenuTemplate(Frame)
        end
        function Skin.WorldMapTrackingOptionsButtonTemplate(Button)
            local shadow = Button:GetRegions()
            shadow:SetPoint("TOPRIGHT", 4, 0)

            Button.Background:Hide()
            Button.IconOverlay:SetAlpha(0)
            Button.Border:Hide()

            local tex = Button:GetHighlightTexture()
            tex:SetTexture([[Interface\Minimap\Tracking\None]], "ADD")
            tex:SetAllPoints(Button.Icon)
        end
        function Skin.WorldMapNavBarButtonTemplate(Frame)
            Skin.NavButtonTemplate()
        end
        function Skin.WorldMapNavBarTemplate(Frame)
            -- Skin.NavBarTemplate(Frame)  -- this is skinned from hooks in NavigationBar.lua
            Frame.InsetBorderBottomLeft:Hide()
            Frame.InsetBorderBottomRight:Hide()
            Frame.InsetBorderBottom:Hide()
            Frame.InsetBorderLeft:Hide()
            Frame.InsetBorderRight:Hide()
        end

        local function SkinQuestToggle(Button, arrowDir)
            Button:SetAllPoints()

            local arrow = Button:CreateTexture(nil, "ARTWORK")
            arrow:SetPoint("TOPLEFT", 5, -9)
            arrow:SetPoint("BOTTOMRIGHT", -20, 9)
            arrow:SetVertexColor(Color.yellow:GetRGB())
            Base.SetTexture(arrow, "arrow"..arrowDir)

            local quest = Button:CreateTexture(nil, "ARTWORK")
            quest:SetTexture([[Interface/QuestFrame/QuestMapLogAtlas]])
            quest:SetTexCoord(0.5390625, 0.556640625, 0.7265625, 0.75)
            quest:SetPoint("TOPLEFT", 14, -5)
            quest:SetPoint("BOTTOMRIGHT", -1, 3)

            Button:SetNormalTexture("")
            Button:SetPushedTexture("")
            Button:SetHighlightTexture("")
            Base.SetBackdrop(Button, Color.button)
            Base.SetHighlight(Button, "backdrop")
        end
        function Skin.WorldMapSidePanelToggleTemplate(Frame)
            SkinQuestToggle(Frame.OpenButton, "Right")
            SkinQuestToggle(Frame.CloseButton, "Left")
        end
        function Skin.WorldMapZoneTimerTemplate(Frame)
        end
    end

    do --[[ Blizzard_WorldMap.xml ]]
        function Skin.WorldMapFrameTemplate(Frame)
            Skin.MapCanvasFrameTemplate(Frame)
            Skin.MapCanvasFrameScrollContainerTemplate(Frame.ScrollContainer)
        end
    end

end

function private.AddOns.Blizzard_WorldMap()
    ----====####$$$$%%%%%$$$$####====----
    --        Blizzard_WorldMap        --
    ----====####$$$$%%%%%$$$$####====----
    local WorldMapFrame = _G.WorldMapFrame
    Skin.WorldMapFrameTemplate(WorldMapFrame)
    Base.SetBackdrop(WorldMapFrame.BorderFrame)
    local bg = WorldMapFrame.BorderFrame:GetBackdropTexture("bg")

    local top1, top2, top3, top4, mid1, mid2, mid3, mid4, bot1, bot2, bot3, bot4, title = WorldMapFrame.BorderFrame:GetRegions()
    top1:Hide()
    top2:Hide()
    top3:Hide()
    top4:Hide()
    mid1:Hide()
    mid2:Hide()
    mid3:Hide()
    mid4:Hide()
    bot1:Hide()
    bot2:Hide()
    bot3:Hide()
    bot4:Hide()

    title:ClearAllPoints()
    title:SetPoint("TOPLEFT", bg)
    title:SetPoint("BOTTOMRIGHT", bg, "TOPRIGHT", 0, -private.FRAME_TITLE_HEIGHT)

    Skin.UIDropDownMenuTemplate(WorldMapFrame.ContinentDropDown)
    Skin.UIDropDownMenuTemplate(WorldMapFrame.ZoneDropDown)
    Skin.UIPanelButtonTemplate(_G.WorldMapZoomOutButton)
    Skin.UIPanelCloseButton(_G.WorldMapFrameCloseButton)
end

