local _, private = ...

--[[ Lua Globals ]]
-- luacheck: globals floor

--[[ Core ]]
local Aurora = private.Aurora
local Base = Aurora.Base
local Hook, Skin = Aurora.Hook, Aurora.Skin
local Color = Aurora.Color

local function SetTexture(texture, anchor, left, right, top, bottom)
    if left then
        texture:SetTexCoord(left, right, top, bottom)
    end
    texture:ClearAllPoints()
    texture:SetPoint("TOPLEFT", anchor, 1, -1)
    texture:SetPoint("BOTTOMRIGHT", anchor, -1, 1)
end
local function SetMicroButton(button, file, left, right, top, bottom)
    --print("SetMicroButton", button:GetName(), file)
    if file == "" then
        if not left then
            --left, right, top, bottom = .19, .81, .21, .82
            left, right, top, bottom = 0.1875, 0.8125, 0.46875, 0.90625
        end
        SetTexture(button._normal, button, left, right, top, bottom)
        SetTexture(button._pushed, button, left, right, top, bottom)
        SetTexture(button._disabled, button, left, right, top, bottom)
    elseif file then
        if not left then
            left, right, top, bottom = 0.2, 0.8, 0.08, 0.92
        end
        button._normal:SetTexture(file)
        SetTexture(button._normal, button, left, right - 0.04, top + 0.04, bottom)

        SetTexture(button._pushed, button, left + 0.04, right, top, bottom - 0.04)
        button._pushed:SetVertexColor(0.5, 0.5, 0.5)
        button._pushed:SetTexture(file)

        SetTexture(button._disabled, button, left, right, top, bottom)
        button._disabled:SetDesaturated(true)
        button._disabled:SetTexture(file)
    else
        button._normal:SetTexture("")
        button._pushed:SetTexture("")
        if button._disabled then
            button._disabled:SetTexture("")
        end
    end
end
SetTexture = Aurora.Profile.trackFunction(SetTexture, "ActionBarController.SetTexture")
SetMicroButton = Aurora.Profile.trackFunction(SetMicroButton, "ActionBarController.SetMicroButton")

do --[[ FrameXML\ActionBarController.lua ]]
    do --[[ MainMenuBar.lua ]]
        function Hook.UpdateMicroButtons()
            if _G.UnitLevel("player") >= _G.SHOW_SPEC_LEVEL then
                _G.QuestLogMicroButton:SetPoint("BOTTOMLEFT", "TalentMicroButton", "BOTTOMRIGHT", 2, 0);
            end
        end
    end
end

do --[[ FrameXML\ActionBarController.xml ]]
    do --[[ MainMenuBarMicroButtons.xml ]]
        function Skin.MainMenuBarMicroButton(Button)
            Button:SetSize(24, 34)

            Button._normal = Button:GetNormalTexture()
            Button._pushed = Button:GetPushedTexture()
            Button._disabled = Button:GetDisabledTexture()

            -- 24 x 34
            Base.SetBackdrop(Button, Color.button)

            Button:SetHighlightTexture("")
            Button.Flash:SetPoint("TOPLEFT", 1, -1)
            Button.Flash:SetPoint("BOTTOMRIGHT", -1, 1)
            Button.Flash:SetTexCoord(.1818, .7879, .175, .875)

            Base.SetHighlight(Button, "backdrop")
        end
        function Skin.MicroButtonAlertTemplate(Frame)
            Skin.GlowBoxTemplate(Frame)
            Skin.UIPanelCloseButton(Frame.CloseButton)
            Skin.GlowBoxArrowTemplate(Frame.Arrow)
        end
    end
    do --[[ ActionButtonTemplate.xml ]]
        function Skin.ActionButtonTemplate(CheckButton)
            Base.CropIcon(CheckButton.icon)

            CheckButton.Flash:SetColorTexture(1, 0, 0, 0.5)
            CheckButton.NewActionTexture:SetAllPoints()
            CheckButton.NewActionTexture:SetTexCoord(0.15, 0.85, 0.15, 0.85)
            CheckButton.SpellHighlightTexture:SetAllPoints()
            CheckButton.SpellHighlightTexture:SetTexCoord(0.15, 0.85, 0.15, 0.85)
            CheckButton.AutoCastable:SetAllPoints()
            CheckButton.AutoCastable:SetTexCoord(0.21875, 0.765625, 0.21875, 0.765625)
            CheckButton.AutoCastShine:ClearAllPoints()
            CheckButton.AutoCastShine:SetPoint("TOPLEFT", 2, -2)
            CheckButton.AutoCastShine:SetPoint("BOTTOMRIGHT", -2, 2)

            CheckButton:SetNormalTexture("")
            Base.CropIcon(CheckButton:GetPushedTexture())
            Base.CropIcon(CheckButton:GetHighlightTexture())
            Base.CropIcon(CheckButton:GetCheckedTexture())
        end
    end
    do --[[ ActionBarFrame.xml ]]
        function Skin.ActionBarButtonTemplate(CheckButton)
            Skin.ActionButtonTemplate(CheckButton)

            Base.CreateBackdrop(CheckButton, {
                bgFile = [[Interface\PaperDoll\UI-Backpack-EmptySlot]],
                tile = false,
                offsets = {
                    left = -1,
                    right = -1,
                    top = -1,
                    bottom = -1,
                }
            })
            CheckButton:SetBackdropColor(1, 1, 1, 0.75)
            CheckButton:SetBackdropBorderColor(Color.frame:GetRGB())
            Base.CropIcon(CheckButton:GetBackdropTexture("bg"))
        end
    end
end

function private.FrameXML.ActionBarController()
    ----====####$$$$%%%%%$$$$####====----
    --     MainMenuBarMicroButtons     --
    ----====####$$$$%%%%%$$$$####====----
    if not private.disabled.mainmenubar then
        _G.hooksecurefunc("UpdateMicroButtons", Hook.UpdateMicroButtons)

        for i, name in _G.ipairs(_G.MICRO_BUTTONS) do
            local button = _G[name]
            Skin.MainMenuBarMicroButton(button)

            local iconTexture, left, right, top, bottom
            if name == "CharacterMicroButton" then
                SetTexture(_G.MicroButtonPortrait, button)
                button:SetPoint("BOTTOMLEFT", _G.MainMenuBarArtFrame, "BOTTOMLEFT", 552, 5)
            elseif name == "SpellbookMicroButton" then
                iconTexture = [[Interface\Icons\INV_Misc_Book_09]]
                button:SetPoint("BOTTOMLEFT", _G.CharacterMicroButton, "BOTTOMRIGHT", 2, 0)
            elseif name == "TalentMicroButton" then
                iconTexture = [[Interface\Icons\Ability_Marksmanship]]
                button:SetPoint("BOTTOMLEFT", _G.SpellbookMicroButton, "BOTTOMRIGHT", 2, 0)
            elseif name == "QuestLogMicroButton" then
                iconTexture = ""
                button:SetPoint("BOTTOMLEFT", _G.TalentMicroButton, "BOTTOMRIGHT", 2, 0)
            elseif name == "SocialsMicroButton" then
                iconTexture = ""
                button:SetPoint("BOTTOMLEFT", _G.QuestLogMicroButton, "BOTTOMRIGHT", 2, 0)
            elseif name == "WorldMapMicroButton" then
                iconTexture = [[Interface\WorldMap\WorldMap-Icon]]
                left, right, top, bottom = 0.21875, 0.6875, 0.109375, 0.8125
                button:SetPoint("BOTTOMLEFT", _G.SocialsMicroButton, "BOTTOMRIGHT", 2, 0)
            elseif name == "MainMenuMicroButton" then
                iconTexture = ""
                button:SetPoint("BOTTOMLEFT", _G.WorldMapMicroButton, "BOTTOMRIGHT", 2, 0)
            elseif name == "HelpMicroButton" then
                iconTexture = [[Interface\Icons\INV_Misc_QuestionMark]]
                button:SetPoint("BOTTOMLEFT", _G.MainMenuMicroButton, "BOTTOMRIGHT", 2, 0)
            end

            SetMicroButton(button, iconTexture, left, right, top, bottom)
        end
    end

    ----====####$$$$%%%%%$$$$####====----
    --           MainMenuBar           --
    ----====####$$$$%%%%%$$$$####====----
    if not private.disabled.mainmenubar then
        -- MainMenuExpBar
        Skin.FrameTypeStatusBar(_G.MainMenuExpBar)
        _G.MainMenuExpBar:SetHeight(9)
        _G.MainMenuExpBar:SetPoint("TOP", 0, 0)
        do
            local divWidth = 1024 / 20
            local xpos = divWidth
            for i = 1, 19 do
                local texture = _G.MainMenuExpBar:CreateTexture(nil, "ARTWORK")
                texture:SetColorTexture(Color.button:GetRGB())
                texture:SetSize(1, 9)

                texture:SetPoint("LEFT", floor(xpos), 0)
                xpos = xpos + divWidth
            end
        end
        _G.ExhaustionLevelFillBar:SetHeight(9)

        -- MainMenuBarArtFrame
        _G.MainMenuXPBarTexture0:SetAlpha(0)
        _G.MainMenuXPBarTexture1:SetAlpha(0)
        _G.MainMenuXPBarTexture2:SetAlpha(0)
        _G.MainMenuXPBarTexture3:SetAlpha(0)

        _G.MainMenuBarTexture0:SetAlpha(0)
        _G.MainMenuBarTexture1:SetAlpha(0)
        _G.MainMenuBarTexture2:SetAlpha(0)
        _G.MainMenuBarTexture3:SetAlpha(0)

        _G.MainMenuBarLeftEndCap:Hide()
        _G.MainMenuBarRightEndCap:Hide()

        -- MainMenuBarPerformanceBarFrame
        Base.SetTexture(_G.MainMenuBarPerformanceBar, "gradientRight")
        _G.MainMenuBarPerformanceBar:SetSize(8, 38)
        _G.MainMenuBarPerformanceBar:SetPoint("TOPRIGHT", -7, -14)
    end

    ----====####$$$$%%%%$$$$####====----
    --      ActionButtonTemplate      --
    ----====####$$$$%%%%$$$$####====----

    ----====####$$$$%%%%$$$$####====----
    --         ActionBarFrame         --
    ----====####$$$$%%%%$$$$####====----
    if not private.disabled.mainmenubar then
        for i = 1, 12 do
            Skin.ActionBarButtonTemplate(_G["ActionButton"..i])
        end
    end

    ----====####$$$$%%%%%$$$$####====----
    --         MultiActionBars         --
    ----====####$$$$%%%%%$$$$####====----

    ----====####$$$$%%%%%$$$$####====----
    --            StanceBar            --
    ----====####$$$$%%%%%$$$$####====----

    ----====####$$$$%%%%%$$$$####====----
    --       ActionBarController       --
    ----====####$$$$%%%%%$$$$####====----
end
