local _, private = ...

--[[ Lua Globals ]]
-- luacheck: globals select

--[[ Core ]]
local Aurora = private.Aurora
local Base, Hook, Skin = Aurora.Base, Aurora.Hook, Aurora.Skin

do --[[ FrameXML\BankFrame.lua ]]
    function Hook.BankFrameItemButton_Update(button)
        local bagID = button:GetParent():GetID()
        local slotID = button:GetID()
        if button.isBag then
            bagID = -4;
        end

        local _, _, _, quality, _, _, link = _G.GetContainerItemInfo(bagID, slotID)
        if not button._auroraIconBorder then
            if button.isBag then
                Skin.BankItemButtonBagTemplate(button)
            else
                Skin.BankItemButtonGenericTemplate(button)
            end

            Hook.SetItemButtonQuality(button, quality, link)
        end

        if link then
            local _, _, _, _, _, _, _, _, _, _, _, itemClassID = _G.GetItemInfo(link)
            if itemClassID == _G.LE_ITEM_CLASS_QUESTITEM then
                button.IconQuestTexture:Show()
                button._auroraIconBorder:SetBackdropBorderColor(1, 1, 0)
            end
        end
    end
end

do --[[ FrameXML\BankFrame.xml ]]
    function Skin.BankItemButtonGenericTemplate(ItemButton)
        Base.CreateBackdrop(ItemButton, {
            bgFile = [[Interface\PaperDoll\UI-Backpack-EmptySlot]],
            tile = false
        })
        Skin.FrameTypeItemButton(ItemButton)
        ItemButton:SetBackdropColor(1, 1, 1, 0.75)
        Base.CropIcon(ItemButton:GetBackdropTexture("bg"))

        ItemButton.IconQuestTexture:SetTexture(_G.TEXTURE_ITEM_QUEST_BORDER)
        Base.CropIcon(ItemButton.IconQuestTexture)
    end
    function Skin.BankItemButtonBagTemplate(ItemButton)
        Skin.FrameTypeItemButton(ItemButton)
        Base.CropIcon(ItemButton.HighlightFrame.HighlightTexture)
    end
end

function private.FrameXML.BankFrame()
    if private.disabled.bags then return end
    _G.hooksecurefunc("BankFrameItemButton_Update", Hook.BankFrameItemButton_Update)

    --[[ BankFrame ]]--
    local BankFrame = _G.BankFrame
    Base.SetBackdrop(BankFrame)
    local bg = BankFrame:GetBackdropTexture("bg")
    bg:SetPoint("TOPLEFT", 14, -14)
    bg:SetPoint("BOTTOMRIGHT", -34, 75)

    local portrait, bankBG = BankFrame:GetRegions()
    portrait:Hide()
    bankBG:Hide()

    _G.BankFrameTitleText:ClearAllPoints()
    _G.BankFrameTitleText:SetPoint("TOPLEFT", bg)
    _G.BankFrameTitleText:SetPoint("BOTTOMRIGHT", bg, "TOPRIGHT", 0, -private.FRAME_TITLE_HEIGHT)

    Skin.UIPanelCloseButton(_G.BankCloseButton)

    local BankSlotsFrame = _G.BankSlotsFrame
    for i = 1, 24 do
        Skin.BankItemButtonGenericTemplate(BankSlotsFrame["Item"..i])
    end

    for i = 1, 6 do
        Skin.BankItemButtonBagTemplate(BankSlotsFrame["Bag"..i])
    end

    for i = 1, select("#", BankSlotsFrame:GetRegions()) do
        select(i, BankSlotsFrame:GetRegions()):Hide()
    end

    Skin.UIPanelButtonTemplate(_G.BankFramePurchaseButton)
    Skin.SmallMoneyFrameTemplate(_G.BankFrameDetailMoneyFrame)
    Skin.SmallMoneyFrameTemplate(_G.BankFrameMoneyFrame)
end
