local _, private = ...

--[[ Lua Globals ]]
-- luacheck: globals next select

--[[ Core ]]
local Aurora = private.Aurora
local Base = Aurora.Base
local Hook, Skin = Aurora.Hook, Aurora.Skin
local Color, Util = Aurora.Color, Aurora.Util

do --[[ FrameXML\FriendsFrame.lua ]]
    Hook.FriendsBroadcastFrameMixin = {}
    function Hook.FriendsBroadcastFrameMixin:ShowFrame()
        self.BroadcastButton:LockHighlight()
    end
    function Hook.FriendsBroadcastFrameMixin:HideFrame()
        self.BroadcastButton:UnlockHighlight()
    end

    function Hook.FriendsFrame_UpdateFriendButton(button)
        local gameIcon = button.gameIcon
        gameIcon._bg:SetShown(gameIcon:IsShown())
    end
end

do --[[ FrameXML\FriendsFrame.xml ]]
    function Skin.FriendsTabTemplate(Button)
        Skin.TabButtonTemplate(Button)
    end
    function Skin.FriendsFrameSlider(Slider)
        Skin.HybridScrollBarTrimTemplate(Slider)
    end
    function Skin.FriendsFrameScrollFrame(ScrollFrame)
        Skin.FriendsFrameSlider(ScrollFrame.scrollBar)
    end
    function Skin.FriendsFrameHeaderTemplate(Frame)
    end
    function Skin.FriendsFrameButtonTemplate(Button)
        Skin.UIPanelButtonTemplate(Button)
    end
    function Skin.FriendsListButtonTemplate(Button)
        local gameIcon = Button.gameIcon
        gameIcon._bg = Base.CropIcon(Button.gameIcon, Button)
        gameIcon:SetSize(22, 22)
        gameIcon:SetTexCoord(0.15625, 0.84375, 0.15625, 0.84375)
        gameIcon:SetPoint("TOPRIGHT", -21, -6)

        local travelPassButton = Button.travelPassButton
        Skin.FrameTypeButton(travelPassButton)

        travelPassButton:SetSize(20, 32)
        travelPassButton:SetNormalTexture("")
        travelPassButton:SetPushedTexture("")
        travelPassButton:SetDisabledTexture("")
        travelPassButton:SetHighlightTexture("")

        travelPassButton._tex = travelPassButton:CreateTexture(nil, "OVERLAY", nil, 7)
        travelPassButton._tex:SetTexture([[Interface\FriendsFrame\PlusManz-PlusManz]])
        travelPassButton._tex:SetPoint("TOPRIGHT", 1, -4)
        travelPassButton._tex:SetSize(22, 22)
        travelPassButton._tex:SetAlpha(0.5)
    end
    function Skin.WhoFrameColumnHeaderTemplate(Button)
        Button.Left:Hide()
        Button.Right:Hide()
        Button.Middle:Hide()
        Button.HighlightTexture:SetAlpha(0)
    end
    function Skin.FriendsFrameGuildPlayerStatusButtonTemplate(Button)
        Button:GetHighlightTexture():SetColorTexture(Color.highlight.r, Color.highlight.g, Color.highlight.b, Color.frame.a)
    end
    function Skin.FriendsFrameGuildStatusButtonTemplate(Button)
        Button:GetHighlightTexture():SetColorTexture(Color.highlight.r, Color.highlight.g, Color.highlight.b, Color.frame.a)
    end
    function Skin.GuildFrameColumnHeaderTemplate(Button)
        local name = Button:GetName()
        _G[name.."Left"]:Hide()
        _G[name.."Middle"]:Hide()
        _G[name.."Right"]:Hide()
    end
    function Skin.FriendsFrameTabTemplate(Button)
        Skin.CharacterFrameTabButtonTemplate(Button)
        Button._auroraTabResize = true
    end
    function Skin.GuildControlPopupFrameCheckboxTemplate(CheckButton)
        Skin.UICheckButtonTemplate(CheckButton)
    end
end

function private.FrameXML.FriendsFrame()
    _G.hooksecurefunc("FriendsFrame_UpdateFriendButton", Hook.FriendsFrame_UpdateFriendButton)

    local FriendsFrame = _G.FriendsFrame
    Skin.ButtonFrameTemplate(FriendsFrame)
    local friendsBG = FriendsFrame:GetBackdropTexture("bg")
    _G.FriendsFrameIcon:Hide()

    ----------------------
    -- FriendsTabHeader --
    ----------------------
    local BNetFrame = _G.FriendsFrameBattlenetFrame
    BNetFrame:GetRegions():Hide() -- BattleTag background
    BNetFrame:SetWidth(245)
    BNetFrame:SetPoint("TOPLEFT", 54, -26)
    Base.SetBackdrop(BNetFrame, _G.FRIENDS_BNET_BACKGROUND_COLOR, Color.frame.a)

    do -- BNetFrame.BroadcastButton
        local Button = BNetFrame.BroadcastButton
        Button:GetNormalTexture():SetAlpha(0)
        Button:GetPushedTexture():SetAlpha(0)
        Button:SetHighlightTexture("")
        local icon = Button:CreateTexture(nil, "ARTWORK")
        icon:SetTexture([[Interface\FriendsFrame\BroadcastIcon]])
        icon:SetSize(16, 16)
        icon:SetPoint("CENTER")

        Base.SetBackdrop(Button, Color.button)
        local bg = Button:GetBackdropTexture("bg")
        bg:SetPoint("TOPLEFT", 5, -5)
        bg:SetPoint("BOTTOMRIGHT", -5, 5)
        Base.SetHighlight(Button, "backdrop")
    end

    Skin.UIPanelInfoButton(BNetFrame.UnavailableInfoButton)

    local BroadcastFrame = BNetFrame.BroadcastFrame
    Skin.DialogBorderOpaqueTemplate(BroadcastFrame)
    BroadcastFrame:SetPoint("TOPLEFT", -55, -24)

    do -- BroadcastFrame.EditBox
        local EditBox = BroadcastFrame.ScrollFrame
        Base.CreateBackdrop(EditBox, private.backdrop, {
            tl = EditBox.TopLeftBorder,
            tr = EditBox.TopRightBorder,
            t = EditBox.TopBorder,

            bl = EditBox.BottomLeftBorder,
            br = EditBox.BottomRightBorder,
            b = EditBox.BottomBorder,

            l = EditBox.LeftBorder,
            r = EditBox.RightBorder,

            bg = EditBox.MiddleBorder
        })
        Skin.FrameTypeEditBox(EditBox)

        local bg = EditBox:GetBackdropTexture("bg")
        bg:ClearAllPoints()
        bg:SetPoint("TOPLEFT", -3, 2)
        bg:SetPoint("BOTTOMRIGHT", 3, -2)
    end

    Skin.FriendsFrameButtonTemplate(BroadcastFrame.ScrollFrame.UpdateButton)
    Skin.FriendsFrameButtonTemplate(BroadcastFrame.ScrollFrame.CancelButton)

    Skin.DialogBorderTemplate(BNetFrame.UnavailableInfoFrame)
    local _, blizzIcon = select(11, BNetFrame.UnavailableInfoFrame:GetRegions())
    blizzIcon:SetTexture([[Interface\Glues\MainMenu\Glues-BlizzardLogo]])

    Skin.UIDropDownMenuTemplate(_G.FriendsFrameStatusDropDown)
    _G.FriendsFrameStatusDropDown:SetPoint("TOPLEFT", -12, -27)
    Skin.FriendsTabTemplate(_G.FriendsTabHeaderTab1)
    Skin.FriendsTabTemplate(_G.FriendsTabHeaderTab2)


    ----------------------
    -- FriendsListFrame --
    ----------------------
    local FriendsListFrame = _G.FriendsListFrame
    Skin.FriendsFrameButtonTemplate(_G.FriendsFrameAddFriendButton)
    Skin.FriendsFrameButtonTemplate(_G.FriendsFrameSendMessageButton)
    Skin.UIDropDownMenuTemplate(FriendsListFrame.FilterDropDown)
    Skin.UIPanelButtonTemplate(FriendsListFrame.RIDWarning:GetChildren()) -- ContinueButton
    _G.FriendsFrameFriendsScrollFrameTop:Hide()
    _G.FriendsFrameFriendsScrollFrameMiddle:Hide()
    _G.FriendsFrameFriendsScrollFrameBottom:Hide()
    Skin.UIMenuButtonStretchTemplate(_G.FriendsFrameFriendsScrollFrame.PendingInvitesHeaderButton)
    Skin.MinimalHybridScrollBarTemplate(_G.FriendsFrameFriendsScrollFrame.scrollBar)
    _G.FriendsFrameFriendsScrollFrame.scrollBar:ClearAllPoints()
    _G.FriendsFrameFriendsScrollFrame.scrollBar:SetPoint("TOPRIGHT", 23, -18)
    _G.FriendsFrameFriendsScrollFrame.scrollBar:SetPoint("BOTTOMRIGHT", 23, 17)
    Hook.HybridScrollFrame_CreateButtons(_G.FriendsFrameFriendsScrollFrame, "FriendsListButtonTemplate") -- Called here since the original is called OnLoad


    ----------------------
    -- IgnoreListFrame --
    ----------------------
    Skin.FriendsFrameButtonTemplate(_G.FriendsFrameIgnorePlayerButton)
    Skin.FriendsFrameButtonTemplate(_G.FriendsFrameUnsquelchButton)
    Skin.FriendsFrameHeaderTemplate(_G.FriendsFrameIgnoredHeader)
    Skin.FriendsFrameHeaderTemplate(_G.FriendsFrameBlockedInviteHeader)
    Skin.FauxScrollFrameTemplate(_G.FriendsFrameIgnoreScrollFrame)


    --------------
    -- WhoFrame --
    --------------
    Skin.InsetFrameTemplate(_G.WhoFrameListInset)
    Skin.WhoFrameColumnHeaderTemplate(_G.WhoFrameColumnHeader1)
    Skin.WhoFrameColumnHeaderTemplate(_G.WhoFrameColumnHeader2)
    Skin.UIDropDownMenuTemplate(_G.WhoFrameDropDown)
    _G.WhoFrameDropDownHighlightTexture:SetAlpha(0)
    Skin.WhoFrameColumnHeaderTemplate(_G.WhoFrameColumnHeader3)
    Skin.WhoFrameColumnHeaderTemplate(_G.WhoFrameColumnHeader4)
    Skin.FriendsFrameButtonTemplate(_G.WhoFrameGroupInviteButton)
    Skin.UIPanelButtonTemplate(_G.WhoFrameAddFriendButton)
    Skin.UIPanelButtonTemplate(_G.WhoFrameWhoButton)
    Skin.InsetFrameTemplate(_G.WhoFrameEditBoxInset)
    Skin.FauxScrollFrameTemplate(_G.WhoListScrollFrame)


    ----------------
    -- GuildFrame --
    ----------------
    local _, _, _, _, barLeft, barRight = _G.GuildFrame:GetRegions()
    barLeft:ClearAllPoints()
    barLeft:SetPoint("TOPLEFT", friendsBG, 10, -325)
    barLeft:SetPoint("BOTTOMRIGHT", friendsBG, "TOPRIGHT", -10, -326)
    barLeft:SetColorTexture(Color.gray:GetRGB())
    barRight:Hide()

    _G.GuildFrameLFGFrameRight:Hide()
    _G.GuildFrameLFGFrameMiddle:Hide()
    _G.GuildFrameLFGFrameLeft:Hide()
    Skin.UICheckButtonTemplate(_G.GuildFrameLFGButton)

    Skin.GuildFrameColumnHeaderTemplate(_G.GuildFrameColumnHeader1)
    Skin.GuildFrameColumnHeaderTemplate(_G.GuildFrameColumnHeader2)
    Skin.GuildFrameColumnHeaderTemplate(_G.GuildFrameColumnHeader3)
    Skin.GuildFrameColumnHeaderTemplate(_G.GuildFrameColumnHeader4)

    for i = 1, _G.GUILDMEMBERS_TO_DISPLAY do
        Skin.FriendsFrameGuildPlayerStatusButtonTemplate(_G["GuildFrameButton"..i])
        Skin.FriendsFrameGuildStatusButtonTemplate(_G["GuildFrameGuildStatusButton"..i])
    end

    Skin.GuildFrameColumnHeaderTemplate(_G.GuildFrameGuildStatusColumnHeader1)
    Skin.GuildFrameColumnHeaderTemplate(_G.GuildFrameGuildStatusColumnHeader2)
    Skin.GuildFrameColumnHeaderTemplate(_G.GuildFrameGuildStatusColumnHeader3)
    Skin.GuildFrameColumnHeaderTemplate(_G.GuildFrameGuildStatusColumnHeader4)

    Skin.FauxScrollFrameTemplate(_G.GuildListScrollFrame)
    local top, bottom = _G.GuildListScrollFrame:GetRegions()
    top:Hide()
    bottom:Hide()

    Skin.NavButtonNext(_G.GuildFrameGuildListToggleButton)
    Skin.UIPanelButtonTemplate(_G.GuildFrameControlButton)
    Skin.UIPanelButtonTemplate(_G.GuildFrameAddMemberButton)
    Skin.UIPanelButtonTemplate(_G.GuildFrameGuildInformationButton)


    ------------------
    -- GuildControl --
    ------------------
    -- /run GuildControlPopupFrame:Show()
    local GuildControlPopupFrame = _G.GuildControlPopupFrame
    Base.SetBackdrop(GuildControlPopupFrame)
    local TopLeft, TopRight, BotLeft, BotRight = _G.GuildControlPopupFrame:GetRegions()
    TopLeft:Hide()
    TopRight:Hide()
    BotLeft:Hide()
    BotRight:Hide()

    Skin.UIDropDownMenuTemplate(_G.GuildControlPopupFrameDropDown)
    do -- Add rank
        local Button = _G.GuildControlPopupFrameAddRankButton
        Skin.FrameTypeButton(Button)
        Button:SetBackdropOption("offsets", {
            left = 0,
            right = 3,
            top = 0,
            bottom = 3,
        })

        local bg = Button:GetBackdropTexture("bg")
        local minus = Button:CreateTexture(nil, "OVERLAY")
        minus:SetPoint("TOPLEFT", bg, 2, -6)
        minus:SetPoint("BOTTOMRIGHT", bg, -2, 6)
        minus:SetColorTexture(1, 1, 1)

        local plus = Button:CreateTexture(nil, "OVERLAY")
        plus:SetPoint("TOPLEFT", bg, 6, -2)
        plus:SetPoint("BOTTOMRIGHT", bg, -6, 2)
        plus:SetColorTexture(1, 1, 1)
    end
    do -- Remove rank
        local Button = _G.GuildControlPopupFrameRemoveRankButton
        Skin.FrameTypeButton(Button)
        Button:SetBackdropOption("offsets", {
            left = 0,
            right = 3,
            top = 0,
            bottom = 3,
        })

        local bg = Button:GetBackdropTexture("bg")
        local minus = Button:CreateTexture(nil, "OVERLAY")
        minus:SetPoint("TOPLEFT", bg, 2, -6)
        minus:SetPoint("BOTTOMRIGHT", bg, -2, 6)
        minus:SetColorTexture(1, 1, 1)
    end

    for i = 1, 13 do
        Skin.GuildControlPopupFrameCheckboxTemplate(_G["GuildControlPopupFrameCheckbox"..i])
    end
    Skin.UIPanelButtonTemplate(_G.GuildControlPopupFrameCancelButton)
    Skin.UIPanelButtonTemplate(_G.GuildControlPopupAcceptButton)
    do
        local EditBox = _G.GuildControlPopupFrameEditBox
        Skin.FrameTypeEditBox(EditBox)

        local _, _, left, right = EditBox:GetRegions()
        left:Hide()
        right:Hide()
    end


    ---------------
    -- GuildMisc --
    ---------------
    local GuildInfoFrame = _G.GuildInfoFrame
    Base.SetBackdrop(GuildInfoFrame)
    local patch, _, corner = GuildInfoFrame:GetRegions()
    patch:SetAlpha(0)
    corner:SetAlpha(0)

    _G.GuildInfoTextBackground:SetBackdrop(nil)

    Skin.UIPanelScrollFrameTemplate(_G.GuildInfoFrameScrollFrame)
    Skin.UIPanelCloseButton(_G.GuildInfoCloseButton)
    Skin.UIPanelButtonTemplate(_G.GuildInfoSaveButton)
    Skin.UIPanelButtonTemplate(_G.GuildInfoCancelButton)


    local GuildMemberDetailFrame = _G.GuildMemberDetailFrame
    Base.SetBackdrop(GuildMemberDetailFrame)

    patch, corner = select(11, GuildMemberDetailFrame:GetRegions())
    patch:SetAlpha(0)
    corner:SetAlpha(0)

    Skin.UIPanelCloseButton(_G.GuildMemberDetailCloseButton)
    Skin.UIPanelButtonTemplate(_G.GuildMemberRemoveButton)
    Skin.UIPanelButtonTemplate(_G.GuildMemberGroupInviteButton)

    Skin.UIPanelScrollUpButtonTemplate(_G.GuildFramePromoteButton)
    Skin.UIPanelScrollDownButtonTemplate(_G.GuildFrameDemoteButton)

    Skin.FrameTypeEditBox(_G.GuildMemberNoteBackground)
    Skin.FrameTypeEditBox(_G.GuildMemberOfficerNoteBackground)


    ----------------------
    -- FriendsFrameMisc --
    ----------------------
    Skin.FriendsFrameTabTemplate(_G.FriendsFrameTab1)
    Skin.FriendsFrameTabTemplate(_G.FriendsFrameTab2)
    Skin.FriendsFrameTabTemplate(_G.FriendsFrameTab3)
    Skin.FriendsFrameTabTemplate(_G.FriendsFrameTab4)
    Skin.FriendsFrameTabTemplate(_G.FriendsFrameTab5)
    Util.PositionRelative("TOPLEFT", FriendsFrame, "BOTTOMLEFT", 20, -1, 1, "Right", {
        _G.FriendsFrameTab1,
        _G.FriendsFrameTab2,
        _G.FriendsFrameTab3,
        _G.FriendsFrameTab4,
        _G.FriendsFrameTab5,
    })

    if not private.disabled.tooltips then
        Base.SetBackdrop(_G.FriendsTooltip)
    end







    --------------------
    -- AddFriendFrame --
    --------------------
    Skin.DialogBorderTemplate(_G.AddFriendFrame)
    Skin.UIPanelButtonTemplate(_G.AddFriendInfoFrameContinueButton)

    Skin.UIPanelInfoButton(_G.AddFriendEntryFrameInfoButton)
    do -- AddFriendNameEditBox
        Skin.FrameTypeEditBox(_G.AddFriendNameEditBox)
        _G.AddFriendNameEditBoxLeft:Hide()
        _G.AddFriendNameEditBoxRight:Hide()
        _G.AddFriendNameEditBoxMiddle:Hide()
    end
    Skin.UIPanelButtonTemplate(_G.AddFriendEntryFrameAcceptButton)
    Skin.UIPanelButtonTemplate(_G.AddFriendEntryFrameCancelButton)







    -------------------------
    -- FriendsFriendsFrame --
    -------------------------
    Skin.DialogBorderTemplate(_G.FriendsFriendsFrame)
    Skin.UIDropDownMenuTemplate(_G.FriendsFriendsFrameDropDown)
    _G.FriendsFriendsList:SetBackdrop(nil)
    Skin.FauxScrollFrameTemplate(_G.FriendsFriendsScrollFrame)
    Skin.UIPanelButtonTemplate(_G.FriendsFriendsSendRequestButton)
    Skin.UIPanelButtonTemplate(_G.FriendsFriendsCloseButton)







    --------------------------
    -- BattleTagInviteFrame --
    --------------------------
    Skin.DialogBorderTemplate(_G.BattleTagInviteFrame)
    local send, cancel = _G.BattleTagInviteFrame:GetChildren()
    Skin.UIPanelButtonTemplate(send)
    Skin.UIPanelButtonTemplate(cancel)
end
