local _, private = ...

--[[ Lua Globals ]]
-- luacheck: globals select

--[[ Core ]]
local Aurora = private.Aurora
local Skin = Aurora.Skin
local Util = Aurora.Util
local F, C = _G.unpack(Aurora)

--do --[[ FrameXML\LootFrame.lua ]]
--end

--do --[[ FrameXML\LootFrame.xml ]]
--end

function private.FrameXML.LootFrame()
    --[[ LootFrame ]]--
    local LootFrame = _G.LootFrame
    Skin.ButtonFrameTemplate(LootFrame)

    _G.LootFramePortraitOverlay:Hide()
    select(19, LootFrame:GetRegions()):SetAllPoints(LootFrame.TitleText) -- Items text

    for index = 1, 4 do
        local Button = _G["LootButton"..index]
        Skin.FrameTypeItemButton(Button)

        local nameFrame = _G["LootButton"..index.."NameFrame"]
        nameFrame:Hide()

        local bg = F.CreateBDFrame(nameFrame, .2)
        bg:SetPoint("TOPLEFT", Button.icon, "TOPRIGHT", 3, 1)
        bg:SetPoint("BOTTOMRIGHT", nameFrame, -5, 11)

        Button:SetNormalTexture("")
        Button:SetPushedTexture("")
    end
    Util.PositionRelative("TOPLEFT", LootFrame, "TOPLEFT", 9, -(private.FRAME_TITLE_HEIGHT + 5), 10, "Down", {
        _G.LootButton1,
        _G.LootButton2,
        _G.LootButton3,
        _G.LootButton4,
    })

    _G.LootFrameDownButton:ClearAllPoints()
    _G.LootFrameDownButton:SetPoint("BOTTOMRIGHT", -8, 6)
    _G.LootFramePrev:ClearAllPoints()
    _G.LootFramePrev:SetPoint("LEFT", _G.LootFrameUpButton, "RIGHT", 4, 0)
    _G.LootFrameNext:ClearAllPoints()
    _G.LootFrameNext:SetPoint("RIGHT", _G.LootFrameDownButton, "LEFT", -4, 0)

    F.ReskinArrow(_G.LootFrameUpButton, "Up")
    F.ReskinArrow(_G.LootFrameDownButton, "Down")

    --[[ MasterLooterFrame ]]--
    local MasterLooterFrame = _G.MasterLooterFrame
    for i = 1, 9 do
        select(i, MasterLooterFrame:GetRegions()):Hide()
    end
    F.CreateBD(MasterLooterFrame)
    F.ReskinClose(select(3, MasterLooterFrame:GetChildren()))

    local item = MasterLooterFrame.Item
    item.NameBorderLeft:Hide()
    item.NameBorderRight:Hide()
    item.NameBorderMid:Hide()
    item._auroraIconBorder = F.ReskinIcon(item.Icon)

    MasterLooterFrame:HookScript("OnShow", function(MLFrame)
        _G.LootFrame:SetAlpha(.4)
    end)

    MasterLooterFrame:HookScript("OnHide", function(MLFrame)
        _G.LootFrame:SetAlpha(1)
    end)

    _G.hooksecurefunc("MasterLooterFrame_UpdatePlayers", function()
        for i = 1, _G.MAX_RAID_MEMBERS do
            local playerFrame = MasterLooterFrame["player"..i]
            if playerFrame then
                if not playerFrame.styled then
                    playerFrame.Bg:SetPoint("TOPLEFT", 1, -1)
                    playerFrame.Bg:SetPoint("BOTTOMRIGHT", -1, 1)
                    playerFrame.Highlight:SetPoint("TOPLEFT", 1, -1)
                    playerFrame.Highlight:SetPoint("BOTTOMRIGHT", -1, 1)

                    playerFrame.Highlight:SetTexture(C.media.backdrop)

                    F.CreateBD(playerFrame, 0)

                    playerFrame.styled = true
                end
                local colour = _G.CUSTOM_CLASS_COLORS[select(2, _G.UnitClass(playerFrame.Name:GetText()))]
                playerFrame.Name:SetTextColor(colour.r, colour.g, colour.b)
                playerFrame.Highlight:SetVertexColor(colour.r, colour.g, colour.b, .2)
            else
                break
            end
        end
    end)
end
